==> nextcloud-app-spreed-1%3A10.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ast.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n convidáu/ada","%n convidaos/es"],
    "Guest" : "Convidáu/ada",
    "Andorra" : "Andorra",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Arxentina",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non válida, el formatu ha ser AAAA-MM-DD",
    "Leave call" : "Dexar llamada",
    "Limit to groups" : "Llendar a grupos",
    "Everyone" : "Toos",
    "Save changes" : "Guardar camudancies",
    "Saving …" : "Guardando...",
    "Saved!" : "¡Guardóse!",
    "None" : "Dengún",
    "User" : "Usuariu",
    "Disabled" : "Deshabilitáu",
    "Users" : "Usuarios",
    "Name" : "Nome",
    "General settings" : "Axustes xenerales",
    "Language" : "Llingua",
    "Country" : "País",
    "Status" : "Estáu",
    "Created at" : "Creóse a les",
    "Pending" : "Pendiente",
    "Error" : "Fallu",
    "Saved" : "Guardóse",
    "TURN server protocols" : "Protocolos del sirvidor TURN",
    "UDP and TCP" : "UDP y TCP",
    "UDP only" : "Namái UDP",
    "TCP only" : "Namái TCP",
    "Copy link" : "Copiar enllaz",
    "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
    "Show your screen" : "Amosar la to pantalla",
    "Stop screensharing" : "Parar compartición de pantalla",
    "Dismiss" : "Escartar",
    "Mute audio" : "Silenciar audiu",
    "Disable video" : "Deshabilitar videu",
    "Enable screensharing" : "Activar compartición de pantalla",
    "Back" : "Atrás",
    "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
    "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Usa un restolador distintu como Firefox o Chrome pa compartir la to pantalla, por favor.",
    "An error occurred while starting screensharing." : "Asocedió un fallu entrín s'aniciaba la compartición de pantalla.",
    "You" : "Tu",
    "Favorite" : "Marcar como favoritu",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Settings" : "Settings",
    "Password protect" : "Protexer con contraseña",
    "Close" : "Zarrar",
    "Reply" : "Rempuesta",
    "Remove" : "Desaniciar",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "Enabled" : "Habilitar",
    "Save" : "Guardar",
    "Password" : "Password",
    "API token" : "Pase d'API",
    "Login" : "Aniciu de sesión",
    "Nickname" : "Nomatu",
    "Client ID" : "ID de veceru",
    "guest" : "invitáu",
    "No results" : "Ensin resultaos",
    "Add users or groups" : "Add users or groups",
    "Edit" : "Editar",
    "Keyboard shortcuts" : "Atayos de tecláu",
    "Search" : "Search",
    "Share link" : "Compartir enllaz",
    "Password protection" : "Password protection",
    "Enter a password" : "Introduz una contraseña",
    "Grid view" : "Vista de rexella",
    "Default" : "Predetermináu",
    "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
    "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
    "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
    "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
    "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "TURN server" : "Sirvidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "Copy" : "Copiar",
    "Copied!" : "¡Copióse!",
    "Not supported!" : "¡Nun se sofita!",
    "Press ⌘-C to copy." : "Primi ⌘-C pa copiar .",
    "Press Ctrl-C to copy." : "Primi Ctrl-C pa copiar.",
    "Cancel" : "Encaboxar",
    "Submit" : "Unviar",
    "Guests" : "Convidaos",
    "Change password" : "Camudar contraseña",
    "Rename" : "Renomar",
    "Send" : "Unviar",
    "Share" : "Share",
    "Error while sharing" : "Fallu entrín se compartía",
    "No other people in this call" : "Nun hai más xente nesta llamada",
    "Waiting for {participantName} to join the call …" : "Esperando que {participantName} se xuna a la llamada...",
    "WebRTC is not supported in your browser :-/" : "WebRTC nun ta sofitao nel to restolador :-/",
    "Waiting for camera and microphone permissions" : "Esperando polos permisos del micrófonu y la cámara",
    "Please, give your browser access to use your camera and microphone in order to use this app." : "Da-y accesu al restolador pa que puea usar la to cámara y micrófonu, y usar esta aplicación.",
    "Share screen" : "Compartir pantalla",
    "Screensharing is not supported by your browser." : "El to restolador nun sofita la compartición de pantalla.",
    "Favorited" : "Favoritos",
    "Your screen" : "La to pantalla",
    "{participantName}'s screen" : "Pantalla de {participantName}",
    "Guest's screen" : "Pantalla de convidáu/ada",
    "Contacts" : "Contautos"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-spreed-1%3A10.0.3-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/spreed/l10n/ast.js <==
OC.L10N.register(
    "spreed",
    {
    "_%n guest_::_%n guests_" : ["%n convidáu/ada","%n convidaos/es"],
    "Guest" : "Convidáu/ada",
    "Andorra" : "Andorra",
    "Anguilla" : "Anguilla",
    "Albania" : "Albania",
    "Armenia" : "Armenia",
    "Angola" : "Angola",
    "Argentina" : "Arxentina",
    "Australia" : "Australia",
    "Aruba" : "Aruba",
    "Invalid date, date format must be YYYY-MM-DD" : "Data non válida, el formatu ha ser AAAA-MM-DD",
    "Leave call" : "Dexar llamada",
    "Limit to groups" : "Llendar a grupos",
    "Everyone" : "Toos",
    "Save changes" : "Guardar camudancies",
    "Saving …" : "Guardando...",
    "Saved!" : "¡Guardóse!",
    "None" : "Dengún",
    "User" : "Usuariu",
    "Disabled" : "Deshabilitáu",
    "Users" : "Usuarios",
    "Name" : "Nome",
    "General settings" : "Axustes xenerales",
    "Language" : "Llingua",
    "Country" : "País",
    "Status" : "Estáu",
    "Created at" : "Creóse a les",
    "Pending" : "Pendiente",
    "Error" : "Fallu",
    "Saved" : "Guardóse",
    "TURN server protocols" : "Protocolos del sirvidor TURN",
    "UDP and TCP" : "UDP y TCP",
    "UDP only" : "Namái UDP",
    "TCP only" : "Namái TCP",
    "Copy link" : "Copiar enllaz",
    "Waiting for others to join the call …" : "Esperando que los otros se xunan a la llamada...",
    "Show your screen" : "Amosar la to pantalla",
    "Stop screensharing" : "Parar compartición de pantalla",
    "Dismiss" : "Escartar",
    "Mute audio" : "Silenciar audiu",
    "Disable video" : "Deshabilitar videu",
    "Enable screensharing" : "Activar compartición de pantalla",
    "Screensharing requires the page to be loaded through HTTPS." : "La compartición de pantalla rique que les páxines carguen pente HTTPS.",
    "Sharing your screen only works with Firefox version 52 or newer." : "Compartir la to pantalla namái funciona con Firefox 52 o más mayor.",
    "Screensharing extension is required to share your screen." : "Ríquese la estensión de compartición de pantalla pa compartir la to pantalla",
    "Please use a different browser like Firefox or Chrome to share your screen." : "Usa un restolador distintu como Firefox o Chrome pa compartir la to pantalla, por favor.",
    "An error occurred while starting screensharing." : "Asocedió un fallu entrín s'aniciaba la compartición de pantalla.",
    "You" : "Tu",
    "Favorite" : "Marcar como favoritu",
    "Remove from favorites" : "Remove from favorites",
    "Add to favorites" : "Add to favorites",
    "Loading" : "Cargando",
    "Groups" : "Grupos",
    "Circles" : "Círculos",
    "Settings" : "Settings",
    "Password protect" : "Protexer con contraseña",
    "Back" : "Atrás",
    "Close" : "Zarrar",
    "Reply" : "Rempuesta",
    "Remove" : "Desaniciar",
    "Today" : "Güei",
    "Yesterday" : "Ayeri",
    "Enabled" : "Habilitar",
    "Save" : "Guardar",
    "Password" : "Password",
    "API token" : "Pase d'API",
    "Login" : "Aniciu de sesión",
    "Nickname" : "Nomatu",
    "Client ID" : "ID de veceru",
    "guest" : "invitáu",
    "No results" : "Ensin resultaos",
    "Add users or groups" : "Add users or groups",
    "Edit" : "Editar",
    "Keyboard shortcuts" : "Atayos de tecláu",
    "Search" : "Search",
    "Share link" : "Compartir enllaz",
    "Password protection" : "Password protection",
    "Enter a password" : "Introduz una contraseña",
    "Grid view" : "Vista de rexella",
    "Send" : "Unviar",
    "Default" : "Predetermináu",
    "Access to microphone & camera is only possible with HTTPS" : "L'accesu a la cámara y micrófonu namái ye posible con HTTPS",
    "Access to microphone & camera was denied" : "Ñegóse l'accesu a la cámara y micrófonu",
    "WebRTC is not supported in your browser" : "WebRTC nun ta sofitao nel to restolador",
    "Please use a different browser like Firefox or Chrome" : "Usa un restoador distintu como Firefox o Chrome, por favor",
    "Error while accessing microphone & camera" : "Fallu entrín s'accedia al micrófonu y cámara",
    "The password is wrong. Try again." : "La contraseña ye incorreuta. Inténtalo otra vegada.",
    "TURN server" : "Sirvidor TURN",
    "The TURN server is used to proxy the traffic from participants behind a firewall." : "El sirvidor TURN úsase pa unviar al proxy el tráficu de los participantes darrera de tornafueos.",
    "Android app" : "Aplicación p'Android",
    "iOS app" : "Aplicación pa iOS",
    "No other people in this call" : "Nun hai más xente nesta llamada",
    "Your screen" : "La to pantalla",
    "Contacts" : "Contautos",
    "Guests" : "Convidaos",
    "Cancel" : "Encaboxar",
    "Submit" : "Unviar"
},
"nplurals=2; plural=(n != 1);");
